==> haskell-wai-logger-2.5.0-134.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-DJcZLrYZUmgA3l0XNoCO69
key:                  wai-logger-2.5.0-DJcZLrYZUmgA3l0XNoCO69
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  06682e40eebcf1c0d7c5d94f60fea35a
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-DJcZLrYZUmgA3l0XNoCO69
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.5.0-135-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-VBPNbjn5lcBUCsraseoRs
key:                  wai-logger-2.5.0-VBPNbjn5lcBUCsraseoRs
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  06d68e282e1dba966921edaa9af207c2
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-VBPNbjn5lcBUCsraseoRs
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
